<?php

/*-----------------------------------------------------------------------------------*/
/* STYLES AND SCRIPTS */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sveva_enqueue_scripts')) {

	function sveva_enqueue_scripts() {

		wp_deregister_style ( 'suevafree-style' );
		wp_deregister_style ( 'suevafree-header_layout_1');
		
		if ( !suevafree_setting( 'sveva_header_layout') || suevafree_setting( 'sveva_header_layout') == 'sveva_header_layout' ) :
		
			wp_enqueue_style( 'sveva-header_layout', get_stylesheet_directory_uri() . '/assets/css/sveva-header-layout.css' );
		
		else:
		
			$header_layout = str_replace('suevafree_', '', suevafree_setting( 'sveva_header_layout'));
			wp_enqueue_style( 'suevafree-' . $header_layout , get_template_directory_uri() . '/assets/css/header/' . $header_layout . '.css' );
		
		endif;

		if ( !get_theme_mod('suevafree_skin') )
			wp_enqueue_style( 'sveva-orange' , get_template_directory_uri() . '/assets/skins/orange.css' ); 

		if ( get_theme_mod('suevafree_skin') ) : 
		
			wp_deregister_style( 'suevafree-' . get_theme_mod('suevafree_skin')); 
			wp_enqueue_style( 'sveva-' . get_theme_mod('suevafree_skin') , get_template_directory_uri() . '/assets/skins/' . get_theme_mod('suevafree_skin') . '.css' ); 
		
		endif;

	}
	
	add_action( 'wp_enqueue_scripts', 'sveva_enqueue_scripts', 99 );

}

/*-----------------------------------------------------------------------------------*/
/* SETUP */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sveva_theme_setup')) {

	function sveva_theme_setup() {

		load_child_theme_textdomain( 'sveva', get_stylesheet_directory() . '/languages' );
		require_once( trailingslashit( get_stylesheet_directory() ) . 'template-part/header-layout.php' );

	}

	add_action( 'after_setup_theme', 'sveva_theme_setup', 11 );

}

/*-----------------------------------------------------------------------------------*/
/* CSS */
/*-----------------------------------------------------------------------------------*/ 

if (!function_exists('sveva_custom_css')) {

	function sveva_custom_css() { 

		$css = '<style type="text/css">';

		if ( get_header_image() )
			
		$css .=  '
			#header.header-9 { 
				background-image: url('.esc_html(get_header_image()).');
				-webkit-background-size: cover !important;
				-moz-background-size: cover !important;
				-o-background-size: cover !important;
				background-size: cover !important;
				background-attachment: fixed;
			}'; 
		
		$css .= '</style>';
		
		echo str_replace( array("\r\n", "\r", "\n", "\t", '  ', '    ', '    '), '', $css);
		
	}

	add_action('wp_head', 'sveva_custom_css');

}

/*-----------------------------------------------------------------------------------*/
/* CUSTOMIZE */
/*-----------------------------------------------------------------------------------*/   

if (!function_exists('sveva_customize_register')) {

	function sveva_customize_register( $wp_customize ) {
	
		$wp_customize->remove_setting( 'suevafree_header_layout');
		$wp_customize->remove_control( 'suevafree_header_layout');
		
		$wp_customize->add_setting( 'sveva_header_layout', array(
			'default' => 'sveva_header_layout',
			'sanitize_callback' => 'sveva_select_sanitize',
		));

		$wp_customize->add_control( 'sveva_header_layout' , array(
									
			'type' => 'select',
			'section' => 'layouts_section',
			'priority' => 1,
			'label' => esc_html__('Header Layout','sveva'),
			'description' => esc_html__('Header Layout','sveva'),
			'choices'  => array (
				'sveva_header_layout' => esc_html__( 'Sveva Header Layout',   'sveva'),
				'suevafree_header_layout_1' => esc_html__( 'SuevaFree Header Layout 1', 'sveva'),
				'suevafree_header_layout_2' => esc_html__( 'SuevaFree Header Layout 2', 'sveva'),
				'suevafree_header_layout_3' => esc_html__( 'SuevaFree Header Layout 3', 'sveva'),
				'suevafree_header_layout_4' => esc_html__( 'SuevaFree Header Layout 4', 'sveva'),
				'suevafree_header_layout_5' => esc_html__( 'SuevaFree Header Layout 5', 'sveva'),
			),
												
		));

		function sveva_select_sanitize ($value, $setting) {
		
			global $wp_customize;
					
			$control = $wp_customize->get_control( $setting->id );
				 
			if ( array_key_exists( $value, $control->choices ) ) {
					
				return $value;
					
			} else {
					
				return $setting->default;
					
			}
			
		}

	}
	
	add_action( 'customize_register', 'sveva_customize_register', 11 );

}

?>